==> 1.0.32.tar.gz: lib/modules/order/order_single_model.dart <==
SingleOrder singleOrderFromJson(dynamic str) => (SingleOrder.fromJson(str));

class SingleOrder {
  late final String sId;
  late final String orderDate;
  late final String orderId;
  late final String bookingId;
  late final int shippingFees;
  late final String paymentStatus;
  late final BillingAddress? billingAddress;
  late final ShippingAddress? shippingAddress;
  late final User? user;
  late final int subTotal;
  late final double totalGst;
  late final double totalAmount;
  late final String orderStatus;
  late final List<OrderItem> orderItem;
  late final String sTypename;

  SingleOrder(
      {required this.sId,
      required this.orderDate,
      required this.orderId,
      required this.bookingId,
      required this.shippingFees,
      required this.paymentStatus,
      required this.billingAddress,
      required this.shippingAddress,
      required this.user,
      required this.subTotal,
      required this.totalGst,
      required this.totalAmount,
      required this.orderStatus,
      required this.orderItem,
      required this.sTypename});

  SingleOrder.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    orderDate = json['orderDate'];
    orderId = json['orderId'];
    bookingId = json['bookingId'];
    shippingFees = json['shippingFees'];
    paymentStatus = json['paymentStatus'];
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new ShippingAddress.fromJson(json['shippingAddress'])
        : null;
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    subTotal = json['subTotal'];
    totalGst = json['totalGst'];
    totalAmount = json['totalAmount'];
    orderStatus = json['orderStatus'];
    if (json['orderItem'] != null) {
      orderItem = [];
      json['orderItem'].forEach((v) {
        orderItem.add(new OrderItem.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['orderDate'] = this.orderDate;
    data['orderId'] = this.orderId;
    data['bookingId'] = this.bookingId;
    data['shippingFees'] = this.shippingFees;
    data['paymentStatus'] = this.paymentStatus;
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    data['subTotal'] = this.subTotal;
    data['totalGst'] = this.totalGst;
    data['totalAmount'] = this.totalAmount;
    data['orderStatus'] = this.orderStatus;
    if (this.orderItem != null) {
      data['orderItem'] = this.orderItem.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class BillingAddress {
  late final String contactName;
  late final String companyName;
  late final String emailId;
  late final int mobileNumber;
  late final String address;
  late final String city;
  late final String state;
  late final String pincode;
  late final String sTypename;

  BillingAddress(
      {required this.contactName,
      required this.companyName,
      required this.emailId,
      required this.mobileNumber,
      required this.address,
      required this.city,
      required this.state,
      required this.pincode,
      required this.sTypename});

  BillingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class ShippingAddress {
  late final String contactName;
  late final String companyName;
  late final String emailId;
  late final int mobileNumber;
  late final String address;
  late final String city;
  late final String state;
  late final int pincode;
  late final String sTypename;

  ShippingAddress(
      {required this.contactName,
      required this.companyName,
      required this.emailId,
      required this.mobileNumber,
      required this.address,
      required this.city,
      required this.state,
      required this.pincode,
      required this.sTypename});

  ShippingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class User {
  late final String contactName;
  late final int mobileNumber;
  late final String? emailId;
  late final String userId;
  late final String sTypename;

  User(
      {required this.contactName,
      required this.mobileNumber,
      required this.emailId,
      required this.userId,
      required this.sTypename});

  User.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    mobileNumber = json['mobileNumber'];
    emailId = json['emailId'];
    userId = json['userId'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['mobileNumber'] = this.mobileNumber;
    data['emailId'] = this.emailId;
    data['userId'] = this.userId;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class OrderItem {
  late final int quantity;
  late final String comments;
  late final String variant;
  late final String variantValue;
  late final int price;
  late final int piece;
  late final double igst;
  late final double cgst;
  late final double sgst;
  late final Pack? pack;
  late final Set? sets;
  late final String sTypename;

  OrderItem(
      {required this.quantity,
      required this.comments,
      required this.variant,
      required this.variantValue,
      required this.price,
      required this.piece,
      required this.igst,
      required this.cgst,
      required this.sgst,
      required this.pack,
      required this.sets,
      required this.sTypename});

  OrderItem.fromJson(Map<String, dynamic> json) {
    quantity = json['quantity'];
    comments = json['comments'];
    variant = json['variant'];
    variantValue = json['variantValue'];
    price = json['price'];
    piece = json['piece'];
    igst = json['igst'];
    cgst = json['cgst'];
    sgst = json['sgst'];
    pack = json['pack'] != null ? new Pack.fromJson(json['pack']) : null;
    sets = json['set'] != null ? new Set.fromJson(json['set']) : null;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['quantity'] = this.quantity;
    data['comments'] = this.comments;
    data['variant'] = this.variant;
    data['variantValue'] = this.variantValue;
    data['price'] = this.price;
    data['piece'] = this.piece;
    data['igst'] = this.igst;
    data['cgst'] = this.cgst;
    data['sgst'] = this.sgst;
    if (this.pack != null) {
      data['pack'] = this.pack!.toJson();
    }
    if (this.sets != null) {
      data['set'] = this.sets!.toJson();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Pack {
  late final List<String> categoryId;
  late final String packSKU;
  late final String packName;
  late final int moq;
  late final String packVariant;
  late final String packImage;
  late final String packId;
  late final String sTypename;

  Pack(
      {required this.categoryId,
      required this.packSKU,
      required this.packName,
      required this.moq,
      required this.packVariant,
      required this.packImage,
      required this.packId,
      required this.sTypename});

  Pack.fromJson(Map<String, dynamic> json) {
    categoryId = json['categoryId'].cast<String>();
    packSKU = json['packSKU'];
    packName = json['packName'];
    moq = json['moq'];
    packVariant = json['packVariant'];
    packImage = json['packImage'];
    packId = json['packId'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['categoryId'] = this.categoryId;
    data['packSKU'] = this.packSKU;
    data['packName'] = this.packName;
    data['moq'] = this.moq;
    data['packVariant'] = this.packVariant;
    data['packImage'] = this.packImage;
    data['packId'] = this.packId;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Set {
  late final String setCode;
  late final String setId;
  late final List<Sku> sku;
  late final String sTypename;

  Set(
      {required this.setCode,
      required this.setId,
      required this.sku,
      required this.sTypename});

  Set.fromJson(Map<String, dynamic> json) {
    setCode = json['setCode'];
    setId = json['setId'];
    if (json['sku'] != null) {
      sku = [];
      json['sku'].forEach((v) {
        sku.add(new Sku.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setCode'] = this.setCode;
    data['setId'] = this.setId;
    if (this.sku != null) {
      data['sku'] = this.sku.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Sku {
  late final int setSkuPrice;
  late final int setQuantity;
  late final String skuId;
  late final String sku;
  late final String styleCode;
  late final String variationType;
  late final int b2cSellingPrice;
  late final int b2bSellingPrice;
  late final int mrp;
  late final int discount;
  late final String productName;
  late final String iNTsku;
  late final String sizeAttributeSettingId;
  late final String sizeAttributeSettingFieldValueId;
  late final String colorAttributeSettingId;
  late final String colorAttributeSettingFieldValueId;
  late final String sizeAttributeName;
  late final String colorAttributeName;
  late final String sizeAttributeFieldValue;
  late final String colorAttributeFieldValue;
  late final String gstTypeId;
  late final int gstValue;
  late final String sTypename;

  Sku(
      {required this.setSkuPrice,
      required this.setQuantity,
      required this.skuId,
      required this.sku,
      required this.styleCode,
      required this.variationType,
      required this.b2cSellingPrice,
      required this.b2bSellingPrice,
      required this.mrp,
      required this.discount,
      required this.productName,
      required this.iNTsku,
      required this.sizeAttributeSettingId,
      required this.sizeAttributeSettingFieldValueId,
      required this.colorAttributeSettingId,
      required this.colorAttributeSettingFieldValueId,
      required this.sizeAttributeName,
      required this.colorAttributeName,
      required this.sizeAttributeFieldValue,
      required this.colorAttributeFieldValue,
      required this.gstTypeId,
      required this.gstValue,
      required this.sTypename});

  Sku.fromJson(Map<String, dynamic> json) {
    setSkuPrice = json['setSkuPrice'];
    setQuantity = json['setQuantity'];
    skuId = json['skuId'];
    sku = json['sku'];
    styleCode = json['styleCode'];
    variationType = json['variationType'];
    b2cSellingPrice = json['b2cSellingPrice'];
    b2bSellingPrice = json['b2bSellingPrice'];
    mrp = json['mrp'];
    discount = json['discount'];
    productName = json['productName'];
    iNTsku = json['INTsku'];
    sizeAttributeSettingId = json['sizeAttributeSettingId'];
    sizeAttributeSettingFieldValueId = json['sizeAttributeSettingFieldValueId'];
    colorAttributeSettingId = json['colorAttributeSettingId'];
    colorAttributeSettingFieldValueId =
        json['colorAttributeSettingFieldValueId'];
    sizeAttributeName = json['sizeAttributeName'];
    colorAttributeName = json['colorAttributeName'];
    sizeAttributeFieldValue = json['sizeAttributeFieldValue'];
    colorAttributeFieldValue = json['colorAttributeFieldValue'];
    gstTypeId = json['gstTypeId'];
    gstValue = json['gstValue'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setSkuPrice'] = this.setSkuPrice;
    data['setQuantity'] = this.setQuantity;
    data['skuId'] = this.skuId;
    data['sku'] = this.sku;
    data['styleCode'] = this.styleCode;
    data['variationType'] = this.variationType;
    data['b2cSellingPrice'] = this.b2cSellingPrice;
    data['b2bSellingPrice'] = this.b2bSellingPrice;
    data['mrp'] = this.mrp;
    data['discount'] = this.discount;
    data['productName'] = this.productName;
    data['INTsku'] = this.iNTsku;
    data['sizeAttributeSettingId'] = this.sizeAttributeSettingId;
    data['sizeAttributeSettingFieldValueId'] =
        this.sizeAttributeSettingFieldValueId;
    data['colorAttributeSettingId'] = this.colorAttributeSettingId;
    data['colorAttributeSettingFieldValueId'] =
        this.colorAttributeSettingFieldValueId;
    data['sizeAttributeName'] = this.sizeAttributeName;
    data['colorAttributeName'] = this.colorAttributeName;
    data['sizeAttributeFieldValue'] = this.sizeAttributeFieldValue;
    data['colorAttributeFieldValue'] = this.colorAttributeFieldValue;
    data['gstTypeId'] = this.gstTypeId;
    data['gstValue'] = this.gstValue;
    data['__typename'] = this.sTypename;
    return data;
  }
}

==> 1.0.39.tar.gz: lib/modules/order/order_single_model.dart <==
SingleOrder singleOrderFromJson(dynamic str) => (SingleOrder.fromJson(str));

class SingleOrder {
  late final String sId;
  late final String orderDate;
  late final String orderId;
  late final String? bookingId;
  late final String? cancellationReason;
  late final String? cancellationDate;
  late final String? returnReason;
  late final String? returnRequestedDate;
  late final String? returnRejectionReason;
  late final double shippingFees;
  late final String? paymentStatus;
  late final BillingAddress? billingAddress;
  late final ShippingAddress? shippingAddress;
  late final User? user;
  late final double subTotal;
  late final double totalGst;
  late final double totalAmount;
  late final String orderStatus;
  late final List<OrderItem> orderItem;
  late final String sTypename;

  SingleOrder(
      {required this.sId,
      required this.orderDate,
      required this.orderId,
      required this.bookingId,
      required this.cancellationReason,
      required this.cancellationDate,
      required this.returnReason,
      required this.returnRequestedDate,
      required this.returnRejectionReason,
      required this.shippingFees,
      required this.paymentStatus,
      required this.billingAddress,
      required this.shippingAddress,
      required this.user,
      required this.subTotal,
      required this.totalGst,
      required this.totalAmount,
      required this.orderStatus,
      required this.orderItem,
      required this.sTypename});

  SingleOrder.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    orderDate = json['orderDate'];
    orderId = json['orderId'];
    bookingId = json['bookingId'];
    cancellationReason = json['cancellationReason'];
    cancellationDate = json['cancellationDate'];
    returnReason = json['returnReason'];
    returnRequestedDate = json['returnRequestedDate'];
    returnRejectionReason = json['returnRejectionReason'];
    shippingFees = json['shippingFees'];
    paymentStatus = json['paymentStatus'];
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new ShippingAddress.fromJson(json['shippingAddress'])
        : null;
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    subTotal = double.parse(json['subTotal'].toString());
    totalGst = json['totalGst'];
    totalAmount = json['totalAmount'];
    orderStatus = json['orderStatus'];
    if (json['orderItem'] != null) {
      orderItem = [];
      json['orderItem'].forEach((v) {
        orderItem.add(new OrderItem.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['orderDate'] = this.orderDate;
    data['orderId'] = this.orderId;
    data['bookingId'] = this.bookingId;
    data['cancellationReason'] = this.cancellationReason;
    data['cancellationDate'] = this.cancellationDate;
    data['returnReason'] = this.returnReason;
    data['returnRequestedDate'] = this.returnRequestedDate;
    data['returnRejectionReason'] = this.returnRejectionReason;

    data['shippingFees'] = this.shippingFees;
    data['paymentStatus'] = this.paymentStatus;
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    data['subTotal'] = this.subTotal;
    data['totalGst'] = this.totalGst;
    data['totalAmount'] = this.totalAmount;
    data['orderStatus'] = this.orderStatus;
    if (this.orderItem != null) {
      data['orderItem'] = this.orderItem.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class BillingAddress {
  late final String? contactName;
  late final String? companyName;
  late final String? emailId;
  late final int? mobileNumber;
  late final String? address;
  late final String? city;
  late final String? state;
  late final int? pincode;
  late final String sTypename;

  BillingAddress(
      {required this.contactName,
      required this.companyName,
      required this.emailId,
      required this.mobileNumber,
      required this.address,
      required this.city,
      required this.state,
      required this.pincode,
      required this.sTypename});

  BillingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class ShippingAddress {
  late final String? contactName;
  late final String? companyName;
  late final String? emailId;
  late final int? mobileNumber;
  late final String? address;
  late final String? city;
  late final String? state;
  late final int? pincode;
  late final String sTypename;

  ShippingAddress(
      {required this.contactName,
      required this.companyName,
      required this.emailId,
      required this.mobileNumber,
      required this.address,
      required this.city,
      required this.state,
      required this.pincode,
      required this.sTypename});

  ShippingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class User {
  late final String? contactName;
  late final int? mobileNumber;
  late final String? emailId;
  late final String userId;
  late final String sTypename;

  User(
      {required this.contactName,
      required this.mobileNumber,
      required this.emailId,
      required this.userId,
      required this.sTypename});

  User.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    mobileNumber = json['mobileNumber'];
    emailId = json['emailId'];
    userId = json['userId'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['mobileNumber'] = this.mobileNumber;
    data['emailId'] = this.emailId;
    data['userId'] = this.userId;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class OrderItem {
  late final int quantity;
  late final String? comments;
  late final String? variant;
  late final String? variantValue;
  late final int price;
  late final int piece;
  late final double igst;
  late final double cgst;
  late final double sgst;
  late final Pack? pack;
  late final Set? sets;
  late final String sTypename;

  OrderItem(
      {required this.quantity,
      required this.comments,
      required this.variant,
      required this.variantValue,
      required this.price,
      required this.piece,
      required this.igst,
      required this.cgst,
      required this.sgst,
      required this.pack,
      required this.sets,
      required this.sTypename});

  OrderItem.fromJson(Map<String, dynamic> json) {
    quantity = json['quantity'];
    comments = json['comments'];
    variant = json['variant'];
    variantValue = json['variantValue'];
    price = json['price'];
    piece = json['piece'];
    igst = json['igst'];
    cgst = json['cgst'];
    sgst = json['sgst'];
    pack = json['pack'] != null ? new Pack.fromJson(json['pack']) : null;
    sets = json['set'] != null ? new Set.fromJson(json['set']) : null;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['quantity'] = this.quantity;
    data['comments'] = this.comments;
    data['variant'] = this.variant;
    data['variantValue'] = this.variantValue;
    data['price'] = this.price;
    data['piece'] = this.piece;
    data['igst'] = this.igst;
    data['cgst'] = this.cgst;
    data['sgst'] = this.sgst;
    if (this.pack != null) {
      data['pack'] = this.pack!.toJson();
    }
    if (this.sets != null) {
      data['set'] = this.sets!.toJson();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Pack {
  late final List<String> categoryId;
  late final String? packSKU;
  late final String? packName;
  late final int? moq;
  late final String? packVariant;
  late final String? packImage;
  late final String packId;
  late final String sTypename;

  Pack(
      {required this.categoryId,
      required this.packSKU,
      required this.packName,
      required this.moq,
      required this.packVariant,
      required this.packImage,
      required this.packId,
      required this.sTypename});

  Pack.fromJson(Map<String, dynamic> json) {
    categoryId = json['categoryId'].cast<String>();
    packSKU = json['packSKU'];
    packName = json['packName'];
    moq = json['moq'];
    packVariant = json['packVariant'];
    packImage = json['packImage'];
    packId = json['packId'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['categoryId'] = this.categoryId;
    data['packSKU'] = this.packSKU;
    data['packName'] = this.packName;
    data['moq'] = this.moq;
    data['packVariant'] = this.packVariant;
    data['packImage'] = this.packImage;
    data['packId'] = this.packId;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Set {
  late final String? setCode;
  late final String? setId;
  late final List<Sku> sku;
  late final String sTypename;

  Set(
      {required this.setCode,
      required this.setId,
      required this.sku,
      required this.sTypename});

  Set.fromJson(Map<String, dynamic> json) {
    setCode = json['setCode'];
    setId = json['setId'];
    if (json['sku'] != null) {
      sku = [];
      json['sku'].forEach((v) {
        sku.add(new Sku.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setCode'] = this.setCode;
    data['setId'] = this.setId;
    if (this.sku != null) {
      data['sku'] = this.sku.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Sku {
  late final int setSkuPrice;
  late final int setQuantity;
  late final String skuId;
  late final String sku;
  late final String styleCode;
  late final String variationType;
  late final int b2cSellingPrice;
  late final int b2bSellingPrice;
  late final int mrp;
  late final int discount;
  late final String productName;
  late final String iNTsku;
  late final String sizeAttributeSettingId;
  late final String sizeAttributeSettingFieldValueId;
  late final String colorAttributeSettingId;
  late final String colorAttributeSettingFieldValueId;
  late final String sizeAttributeName;
  late final String colorAttributeName;
  late final String sizeAttributeFieldValue;
  late final String colorAttributeFieldValue;
  late final String gstTypeId;
  late final int gstValue;
  late final String sTypename;

  Sku(
      {required this.setSkuPrice,
      required this.setQuantity,
      required this.skuId,
      required this.sku,
      required this.styleCode,
      required this.variationType,
      required this.b2cSellingPrice,
      required this.b2bSellingPrice,
      required this.mrp,
      required this.discount,
      required this.productName,
      required this.iNTsku,
      required this.sizeAttributeSettingId,
      required this.sizeAttributeSettingFieldValueId,
      required this.colorAttributeSettingId,
      required this.colorAttributeSettingFieldValueId,
      required this.sizeAttributeName,
      required this.colorAttributeName,
      required this.sizeAttributeFieldValue,
      required this.colorAttributeFieldValue,
      required this.gstTypeId,
      required this.gstValue,
      required this.sTypename});

  Sku.fromJson(Map<String, dynamic> json) {
    setSkuPrice = json['setSkuPrice'];
    setQuantity = json['setQuantity'];
    skuId = json['skuId'];
    sku = json['sku'];
    styleCode = json['styleCode'];
    variationType = json['variationType'];
    b2cSellingPrice = json['b2cSellingPrice'];
    b2bSellingPrice = json['b2bSellingPrice'];
    mrp = json['mrp'];
    discount = json['discount'];
    productName = json['productName'];
    iNTsku = json['INTsku'];
    sizeAttributeSettingId = json['sizeAttributeSettingId'];
    sizeAttributeSettingFieldValueId = json['sizeAttributeSettingFieldValueId'];
    colorAttributeSettingId = json['colorAttributeSettingId'];
    colorAttributeSettingFieldValueId =
        json['colorAttributeSettingFieldValueId'];
    sizeAttributeName = json['sizeAttributeName'];
    colorAttributeName = json['colorAttributeName'];
    sizeAttributeFieldValue = json['sizeAttributeFieldValue'];
    colorAttributeFieldValue = json['colorAttributeFieldValue'];
    gstTypeId = json['gstTypeId'];
    gstValue = json['gstValue'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setSkuPrice'] = this.setSkuPrice;
    data['setQuantity'] = this.setQuantity;
    data['skuId'] = this.skuId;
    data['sku'] = this.sku;
    data['styleCode'] = this.styleCode;
    data['variationType'] = this.variationType;
    data['b2cSellingPrice'] = this.b2cSellingPrice;
    data['b2bSellingPrice'] = this.b2bSellingPrice;
    data['mrp'] = this.mrp;
    data['discount'] = this.discount;
    data['productName'] = this.productName;
    data['INTsku'] = this.iNTsku;
    data['sizeAttributeSettingId'] = this.sizeAttributeSettingId;
    data['sizeAttributeSettingFieldValueId'] =
        this.sizeAttributeSettingFieldValueId;
    data['colorAttributeSettingId'] = this.colorAttributeSettingId;
    data['colorAttributeSettingFieldValueId'] =
        this.colorAttributeSettingFieldValueId;
    data['sizeAttributeName'] = this.sizeAttributeName;
    data['colorAttributeName'] = this.colorAttributeName;
    data['sizeAttributeFieldValue'] = this.sizeAttributeFieldValue;
    data['colorAttributeFieldValue'] = this.colorAttributeFieldValue;
    data['gstTypeId'] = this.gstTypeId;
    data['gstValue'] = this.gstValue;
    data['__typename'] = this.sTypename;
    return data;
  }
}
